<?php declare(strict_types = 1);

namespace Drupal\notify_widget\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Notify Widget settings for this site.
 */
final class NotifyWidgetSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'notify_widget_notify_widget_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['notify_widget.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['max_notifications'] = [
      '#type' => 'number',
      '#title' => $this->t('Maximum Notifications to Display'),
      '#description' => $this->t('Select the maximum number of notifications to display in the popup overlay.'),
      '#default_value' => $this->config('notify_widget.settings')->get('max_notifications') ?? 10,
      '#required' => TRUE,
      '#min' => 1,
      '#max' => 5000,
      '#step' => 1,
    ];

    $form['use_module_css'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use Module CSS'),
      '#description' => $this->t('Check this box to use the CSS included with the module. If you want to use your own CSS, uncheck this and target the #notify_widget element with your own CSS.'),
      '#default_value' => $this->config('notify_widget.settings')->get('use_module_css') ?? 1,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('notify_widget.settings')
      ->set('max_notifications', $form_state->getValue('max_notifications'))
      ->set('use_module_css', $form_state->getValue('use_module_css'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
